%global shortver 83
%global macrosdir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)

Name:		grass
Version:	8.3.2
Release:    1%{?dist}
Summary:	GRASS GIS - Geographic Resources Analysis Support System

%bcond_without flexiblas

%bcond_without python3

%undefine _package_note_file

License:	GPL-2.0-or-later
URL:		https://grass.osgeo.org
Source0:	https://grass.osgeo.org/%{name}%{shortver}/source/%{name}-%{version}.tar.gz

Patch 0:	grass-pkgconfig.patch
Patch1:		grass-c99.patch

BuildRequires:	bison
%if %{with flexiblas}
BuildRequires:	flexiblas-devel
%else
BuildRequires:	blas-devel, lapack-devel
%endif
BuildRequires:	cairo-devel
BuildRequires:	gcc-c++
BuildRequires:	desktop-file-utils
BuildRequires:	fftw-devel
BuildRequires:	flex
BuildRequires:	freetype-devel
BuildRequires:	gdal-devel
BuildRequires:	geos-devel
BuildRequires:	gettext
BuildRequires:	laszip-devel
BuildRequires:	libappstream-glib
BuildRequires:	libpng-devel
BuildRequires:	libtiff-devel
BuildRequires:	libXmu-devel
BuildRequires:	mesa-libGL-devel
BuildRequires:	mesa-libGLU-devel
BuildRequires:	mariadb-connector-c-devel openssl-devel
BuildRequires:	netcdf-devel
BuildRequires:	python3
BuildRequires:	python3-numpy
BuildRequires:	libpq-devel
BuildRequires:	proj-devel
BuildRequires:	python3-dateutil
BuildRequires:	python3-devel
BuildRequires:	python3-pillow
BuildRequires:	PDAL
BuildRequires:	PDAL-libs
BuildRequires:	PDAL-devel
BuildRequires:	readline-devel
BuildRequires:	sqlite-devel
BuildRequires:	subversion
BuildRequires:	unixODBC-devel
BuildRequires:	zlib-devel
BuildRequires:	bzip2-devel
BuildRequires:	libzstd-devel
BuildRequires: make

Requires:	bzip2-libs
Requires:	libzstd
Requires:	geos
Requires:	python3
Requires:	python3-numpy
Requires:	python3-dateutil
Requires:	python3-wxpython4
Requires:	PDAL
Requires:	PDAL-libs

%if "%{_lib}" == "lib"
%global cpuarch 32
%else
%global cpuarch 64
%endif

Requires:	%{name}-libs = %{version}-%{release}

%description
GRASS (Geographic Resources Analysis Support System) is a Geographic
Information System (GIS) used for geospatial data management and
analysis, image processing, graphics/maps production, spatial
modeling, and visualization. GRASS is currently used in academic and
commercial settings around the world, as well as by many governmental
agencies and environmental consulting companies.

%package libs
Summary:	GRASS GIS runtime libraries

%description libs
GRASS GIS runtime libraries

%package gui
Summary:	GRASS GIS GUI
Requires:	%{name} = %{version}-%{release}

%description gui
GRASS GIS GUI

%package devel
Summary:	GRASS GIS development headers
Requires:	%{name}-libs = %{version}-%{release}

%description devel
GRASS GIS development headers

%prep
%setup -q
%patch 0 -p1 -b.libdir
%patch -P 1 -p1

sed -i -e 's/--libmysqld-libs/--libs/g' configure

%if %{with flexiblas}
sed -i -e 's/-lblas/-lflexiblas/g' -e 's/-llapack/-lflexiblas/g' configure
%endif

find -name \*.pl | xargs sed -i -e 's,#!/usr/bin/env perl,#!%{__perl},'

%build
%configure \
	--prefix=%{_libdir} \
	--with-cxx \
	--with-tiff \
	--with-postgres \
	--with-mysql \
	--with-opengl \
	--with-odbc \
	--with-fftw \
	--with-blas \
	--with-lapack \
%if %{with flexiblas}
	--with-blas-includes=%{_includedir}/flexiblas \
	--with-lapack-includes=%{_includedir}/flexiblas \
%endif
	--with-cairo \
	--with-freetype \
	--with-nls \
	--with-pdal \
	--with-readline \
	--with-regex \
	--with-openmp \
	--with-gdal=%{_bindir}/gdal-config \
	--with-geos=%{_bindir}/geos-config \
	--with-netcdf=%{_bindir}/nc-config \
	--with-mysql-includes=%{_includedir}/mysql \
	--with-mysql-libs=%{_libdir} \
	--with-postgres-includes=%{_includedir}/pgsql \
	--with-cairo-ldflags=-lfontconfig \
	--with-freetype-includes=%{_includedir}/freetype2 \
	--with-bzlib \
	--with-zstd \
	--with-proj-share=%{_datadir}/proj

sed -i "s+ -Wl,-dT,${RPM_BUILD_DIR}/grass-%{version}/.package_note-grass-%{version}-%{release}.%{_arch}.ld++g" include/Make/Platform.make

make %{?_smp_mflags}

%install
%make_install \
	DESTDIR=%{buildroot} \
	prefix=%{_libdir} \
	UNIX_BIN=%{_bindir} \
	GISBASE_RUNTIME=%{_libdir}/%{name}%{shortver}


sed -i -e 's|%{_libdir}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
	%{name}.pc

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig

mv %{buildroot}%{_libdir}/%{name}%{shortver}/include/%{name}/config.h \
   %{buildroot}%{_libdir}/%{name}%{shortver}/include/%{name}/config-%{cpuarch}.h
echo '#include <bits/wordsize.h>

#if __WORDSIZE == 32
#include "grass/config-32.h"
#else
#if __WORDSIZE == 64
#include "grass/config-64.h"
#else
#error "Unknown word size"
#endif
#endif' > %{buildroot}%{_libdir}/%{name}%{shortver}/include/%{name}/config.h
chmod 644 %{buildroot}%{_libdir}/%{name}%{shortver}/include/%{name}/config.h

mkdir -p %{buildroot}%{_mandir}/man1
for man in $(ls %{buildroot}%{_libdir}/%{name}%{shortver}/docs/man/man1/*.1)
do
	iconv -f iso8859-1 -t utf8 $man > %{buildroot}%{_mandir}/man1/$(basename $man)"%{name}"
done

mkdir -p %{buildroot}%{_docdir}
ln -s %{_libdir}/%{name}%{shortver}/docs %{buildroot}%{_docdir}/%{name}%{shortver}

mv %{buildroot}%{_libdir}/%{name}%{shortver}/share/* %{buildroot}%{_datadir}
desktop-file-validate %{buildroot}/%{_datadir}/applications/*.desktop
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/org.osgeo.%{name}.appdata.xml



# rpm macro for version checking (not from buildroot!)
mkdir -p ${RPM_BUILD_ROOT}%{macrosdir}
cat > ${RPM_BUILD_ROOT}%{macrosdir}/macros.%{name} <<EOF
%%%{name}_version %{version}
EOF

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat >  %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf<<EOF
%{_libdir}/%{name}%{shortver}/lib
EOF

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%exclude %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%exclude %{_libdir}/%{name}%{shortver}/driver/db/*
%exclude %{_libdir}/%{name}%{shortver}/lib
%exclude %{_libdir}/%{name}%{shortver}/include
%exclude %{_libdir}/%{name}%{shortver}/gui
%{_libdir}/%{name}%{shortver}
%{_bindir}/*
%{_datadir}/metainfo/*
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man1/*
%{_docdir}/%{name}%{shortver}

%files libs
%license AUTHORS COPYING GPL.TXT CHANGES
%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_libdir}/%{name}%{shortver}/lib/*.so
%dir %{_libdir}/%{name}%{shortver}/driver
%dir %{_libdir}/%{name}%{shortver}/driver/db
%{_libdir}/%{name}%{shortver}/driver/db/*

%files gui
%{_libdir}/%{name}%{shortver}/gui

%files devel
%doc TODO doc/* CONTRIBUTING.md
%{macrosdir}/macros.%{name}
%{_libdir}/pkgconfig/*
%dir %{_libdir}/%{name}%{shortver}/lib
%{_libdir}/%{name}%{shortver}/include

%changelog
* Mon Aug 19 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.3.2-1
- initial build
